MigrationStore

Trait MigrationStore 

pub trait MigrationStore {
    // Required method
    fn changelogs(&self) -> Vec<ChangelogFile>;
}
Struct storing the changelogs needed for the migrations

Implementations of this trait will usually be generated by the migrations macro, but can also be created manually.

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors